@@ -1,12 +1,30 @@
-from dagster import SolidDefinition
+from dagster import DagsterType, SolidDefinition
+from dask.dataframe import DataFrame as DaskDataFrame
+from pandas import DataFrame
 from qdk import DataFrameLoader, DataFrameType
 
 from ..utils.dataframe import (
     CSVStoreDataFrame,
     JSONStoreDataFrame,
     PickleStoreDataFrame,
+    StoreDataFrame,
 )
 
+def test_compute_ddf(tmpdir):
+    """Test computer_dff parameter of DataFrameLoader.
+
+    Args:
+        tmpdir (str): The path to the temporary directory created by pytest
+    """
+    df_storer = CSVStoreDataFrame()
+    df_path = df_storer.store_dataframe(tmpdir)
+
+    lazy_ddf = DataFrameLoader.load(df_path, use_dask=True)
+    computed_ddf = DataFrameLoader.load(df_path, use_dask=True, compute_ddf=True)
+
+    assert isinstance(lazy_ddf, DaskDataFrame)
+    assert isinstance(computed_ddf, DataFrame)
+
 
 def test_csv_loading(tmpdir):
     """Test loading a csv file.
